/**
 * Represents the different parts necessary to build an Azure Blob URL
 */
interface BlobStorageUrlParts {
    /**
     * The unique blob storage account name
     */
    account: string;
    /**
     * The container within the blob storage account
     */
    container: string;
    /**
     * The path to any blob within the blob storage container
     */
    path?: string;
    /**
     * The secure access signature (SAS) token necessary to authenticate access to the Blob URL
     */
    sasToken?: string;
}
/**
 * Represents the options available when using the localFile() function
 */
interface SyncLocalFileOptions {
    /**
     * The destination Blob URL parts necessary to build out the location of where to put the local file
     */
    destination: BlobStorageUrlParts;
    /**
     * The local file path to a blob to be used when syncing to the destination
     */
    localFilePath: string;
}
/**
 * Represents the options available when using the containers()
 */
interface SyncContainersOptions {
    deleteDestination: boolean;
    destination: BlobStorageUrlParts;
    recursive: boolean;
    source: BlobStorageUrlParts;
}
declare const AzcopySync: {
    /**
     * Syncs a local file from the calling machine to the provided destination blob storage container
     *
     * @param options Options bag with all available parameters
     */
    localFile(options: SyncLocalFileOptions): void;
    /**
     * Syncs the provided source container with the provided destination container
     *
     * @param options Options bag with all available parameters
     */
    containers(options: SyncContainersOptions): void;
};
export { AzcopySync, BlobStorageUrlParts, SyncContainersOptions, SyncLocalFileOptions, };
