import { CommandStringBuilder } from "../utilities/command-string-builder";
import { OptionStringBuilder } from "../utilities/option-string-builder";
import { ExecOutputReturnValue } from "shelljs";
/**
 * @example
 * // An example of the result object to be returned. Code = 0 signifies a successful run,
 * // while any other code signifies a failure.
 *  {
 *      code: 1,
 *      name: "ExampleProject.Core.Tests",
 *      stderr: "...",
 *      stdout: "...",
 *  }
 */
interface ProjectTestResult extends Pick<ExecOutputReturnValue, "stderr">, Pick<ExecOutputReturnValue, "stdout"> {
    code: number;
    name: string;
}
declare const DotnetTest: {
    ciMode(ciMode?: boolean | undefined): any;
    cmd(): CommandStringBuilder;
    description(): string;
    getOptions(): Record<string, OptionStringBuilder>;
    filter(filter?: string[] | undefined): any;
    /**
     * Runs dotnet test synchronously for the given test project
     *
     * @param {string} project The name of the test project to be run.
     * @returns {ProjectTestResult} An object containing the project name, exit code, and stdout/stderr if 'ciMode' is true.
     */
    runProject(project: string): ProjectTestResult;
    runSolutionByProject(): number;
    runBySolution(): void;
    skipClean(skipClean?: boolean | undefined): any;
    withCoverage(withCoverage?: boolean | undefined): any;
};
export { DotnetTest };
