declare const Git: {
    /**
     * Configures a new remote when run in root of git repository
     * @param {string} name local identifier for a new remote
     * @param {string} url absolute url corresponding to remote destination
     */
    addRemote(name: string, url: string): boolean;
    /**
     * Clone a git repository
     * @param {string} name Name of repository being cloned
     * @param {string} url Absolute HTTPS or SSH repository URL
     * @param {string} prefix Prefix for destination folder '{FOLDER_PREFIX}.{REPOSITORY_NAME}'
     */
    clone(name: string, url: string, prefix?: string | undefined): boolean;
    /**
     * Constructs target folder name given a repo and optional prefix
     * @param {string} repoName short name of repository
     * @param {string} prefix optional prefix
     */
    getCloneDirectoryName(repoName: string, prefix?: string | undefined): string;
    /**
     * Checks if the repository is cloned for the supplied combination
     * @param {string} repoName short name of repository
     * @param {string} prefix optional prefix
     */
    isCloned(repoName: string, prefix?: string | undefined): boolean;
    /**
     * Verifies if we are in a git repo
     */
    isRepositoryRoot(): boolean;
    /**
     * Opens the supplied URL in the system's default browser
     * @param {string} url absolute url
     */
    openWebBrowser(url: string): void;
};
export { Git };
