declare const Js: {
    /**
     * Version of foreach supporting async/await
     * @param {array} array array of objects for which to iterate
     * @param {function} callback function to invoke upon each iteration
     */
    asyncForEach<T>(array: T[], callback: (value: T, index?: number | undefined, array?: T[] | undefined) => Promise<void>): Promise<void>;
    /**
     * Is the current command without arguments?
     */
    hasNoArguments(): boolean;
    /**
     * Invokes provided callback at the supplied interval until a duration is met
     *
     * The callback will be invoked immediately.
     * @param {function} callbackAsync async function to evaluates every interval. if function returns 'true', wait period is ended.
     *      provided function is also provided the current elapsed time.
     * @param {number} interval number of milliseconds to wait between invocations of 'callback'
     * @param {number} [duration] duration of attempts in milliseconds
     * @param {function} [timeoutCallback] function invoked if the duration is met. callback is provided exact elapsed time
     */
    waitFor(callbackAsync: Function, interval: number, duration: number, timeoutCallback?: Function | undefined): Promise<void>;
};
export { Js };
