/**
 * Module to wrap access to the package.json file. Any reading/transforming of data from that file
 * should live here.
 */
declare const PackageConfig: {
    /**
     * Default object to be returned if the 'and-cli' section of the package.json is missing
     */
    DEFAULT_CONFIG: {
        [x: string]: {};
    };
    /**
     * Object to hold constants for each supported config under the 'and-cli' section
     */
    SECTIONS: {
        ALIASES: string;
    };
    /**
     * Returns the package.json file for the base `and-cli` package.
     */
    getBase(): any;
    /**
     * Returns the 'description' field from the package.json file of the base `and-cli` package.
     */
    getBaseDescription(): any;
    /**
     * Returns the 'version' field from the package.json file of the base `and-cli` package.
     */
    getBaseVersion(): any;
    /**
     * Returns the package.json file nearest to the current directory. Use this if you need to
     * retrieve the package.json file for your local project and not the base package.json.
     *
     * Note that this will traverse upwards from the current directory to look for a package.json,
     * and return the first match. If no package.json is found, it will return the base package.json
     */
    getLocal(): any;
    /**
     * Returns the first binary name from the local package.json file. If no 'bin' section exists,
     * or it contains no values, it returns `undefined`. If multiple keys exist, only the first will
     * be returned.
     */
    getLocalBinName(): string | undefined;
    /**
     * Returns the 'and-cli' config section for the currently executing package, or a default object.
     */
    getLocalAndCliConfigOrDefault(): any;
};
export { PackageConfig };
