import { AsyncReadlineInterface } from "../interfaces/async-readline-interface";
declare const Prompt: {
    /**
     * Prompts the user for confirmation, and exits if the user does not type y or Y.
     *
     * @param question Question to ask the user for input
     * @param exitStatus Exit status to pass to shelljs if confirmation unsuccessful
     */
    confirmOrExit(question: string, exitStatus?: number): Promise<void>;
    getInterface(): AsyncReadlineInterface;
    /**
     * Returns a multiline prompt that returns a string array of the responses. A terminator phrase
     * is required to end the interaction, which defaults to an empty string - hitting enter without
     * any additional input.
     *
     * @param question Question to ask the user for input
     * @param terminatorPhrase String to terminate the input loop
     */
    multiline(question: string, terminatorPhrase?: string): Promise<string[]>;
    /**
     * Wrapper function around the underlying `prompt.questionAsync` function to reduce the amount of
     * work a consumer has to do to prompt the user
     *
     * @param question Question to ask the user for input
     */
    questionAsync(question: string): Promise<string>;
};
export { Prompt };
