import { CommandDefinition } from "../interfaces/command-definition";
/**
 * Utility functions related to working with `CommandDefinition` objects
 */
declare const CommandDefinitionUtils: {
    /**
     * Returns whether or not a definition of the matching name (case-insensitive) exists in the
     * provided map
     *
     * @param name Name of the definition to find
     * @param map Collection of definitions to check
     */
    exists(name: string, map?: Record<string, CommandDefinition> | undefined): boolean;
    /**
     * Flattens the first level of a map to an array.
     *
     * @param map Collection of definitions to flatten to an array
     */
    flatten(map?: Record<string, CommandDefinition> | undefined): CommandDefinition[];
    /**
     * Returns a definition of the matching name (case-insensitive) in the provided collection
     *
     * @param name Name of the definition to find
     * @param map Collection of definitions to check
     */
    get(name: string, map?: Record<string, CommandDefinition> | undefined): CommandDefinition | undefined;
    /**
     * Returns an array of the first level of command names
     *
     * @param map Collection of definitions to retrieve names from
     */
    getNames(map?: Record<string, CommandDefinition> | undefined): string[];
    /**
     * Returns whether or not a definition of the matching name exists in the base `and-cli` map
     *
     * @param name Name of the definition to check
     */
    isBase(name: string): boolean;
    /**
     * Sets the default map of CommandDefinitions to be used when not passed in as a parameter to
     * any of the functions in this utility module.
     *
     * @default `CommandDefinitions` module
     * @param map Collection of definitions to be used as a default map
     *
     * @returns `this` for chaining
     */
    setDefault(map: Record<string, CommandDefinition>): any;
    /**
     * Converts the first level of definitions in the provided map to a comma separated string
     *
     * @param map Collection of definitions to convert to a string
     * @returns Comma separated string of definition names
     */
    toCsv(map?: Record<string, CommandDefinition> | undefined): string;
};
export { CommandDefinitionUtils };
