import program from "commander";
/**
 * Utility functions related to working with `program.Command` objects
 */
declare const CommandUtils: {
    /**
     * Returns true if the command matches the given name (case insensitive)
     *
     * @param name Name of the command for comparison
     * @param command Command for comparison
     * @returns {boolean}
     */
    equalsByName(name: string, command?: program.Command | undefined): boolean;
    /**
     * Returns whether or not a command of the matching name (case-insensitive) is registered under
     * the provided command
     *
     * @param {program.Command} command Command to check
     * @param {string} name Name of the command to find
     */
    exists(name: string, command?: program.Command | undefined): boolean;
    /**
     * Returns a registered command by name. If the command is not registered under the
     * provided command, returns `undefined`
     *
     * @param command Command to retrieve from
     * @param name Name of the command to retrieve
     */
    get(name: string, command?: program.Command | undefined): program.Command | undefined;
    /**
     * Removes a subcommand from the provided command by name.
     *
     * @param command Command to remove from
     * @param name Name of the command to remove
     */
    remove(name: string, command?: program.Command | undefined): program.Command;
    /**
     * Sets the default command to be used when not passed in as a parameter to any of the
     * functions in this utility module.
     *
     * @default program
     * @param command Command to be used as the default
     *
     * @returns `this` for chaining
     */
    setDefault(command: program.Command): any;
    /**
     * Sorts the underlying command list alphabetically by name
     */
    sort(command?: program.Command | undefined): program.Command;
};
export { CommandUtils };
